DetectedEncoding

Enum DetectedEncoding 

pub enum DetectedEncoding {
    AsciiCompatible,
    Utf8Bom,
    Utf16LeLike,
    Utf16LeBom,
    Utf16BeLike,
    Utf16BeBom,
}
Possible scenarios for start-of-xml detection of encoding

See the documentation of detect_encoding

Variants



AsciiCompatible

Matches UTF-8 or some other ascii-compatible encoding



Utf8Bom

We saw a UTF-8 BOM



Utf16LeLike

Matches UTF-16-LE or some other UTF-16 compatible encoding (e.g. ISO-10646-UCS-2)



Utf16LeBom

We saw a UTF-16 BOM in little-endian orientation



Utf16BeLike

Matches UTF-16-BE or some other UTF-16 compatible encoding (e.g. ISO-10646-UCS-2)



Utf16BeBom

We saw a UTF-16 BOM in big-endian orientation

Implementations

Source

impl DetectedEncoding

pub const fn encoding(&self) -> &'static Encoding

Available on crate feature encoding only.

Return an Encoding object appropriate for the detected encoding

pub const fn bom_len(&self) -> usize

Length of the BOM, which may need to be stripped from the input