pub struct Decoder { /* private fields */ }Expand description
Decoder of byte slices into strings.
If feature encoding is enabled, this encoding taken from the "encoding"
XML declaration or assumes UTF-8, if XML has no declaration, encoding
key is not defined or contains unknown encoding.
The library supports any UTF-8 compatible encodings that crate encoding_rs
is supported. UTF-16 and ISO-2022-JP are not supported at the present.
If feature encoding is disabled, the decoder is always UTF-8 decoder:
any XML declarations are ignored.