pub enum SyntaxError {
InvalidBangMarkup,
UnclosedPI,
UnclosedXmlDecl,
UnclosedComment,
UnclosedDoctype,
UnclosedCData,
UnclosedTag,
UnclosedSingleQuotedAttributeValue,
UnclosedDoubleQuotedAttributeValue,
}Expand description
An error returned if parsed document does not correspond to the XML grammar,
for example, a tag opened by < not closed with >. This error does not
represent invalid XML constructs, for example, tags <> and </> a well-formed
from syntax point-of-view.
Variants
InvalidBangMarkup
The parser started to parse <!, but the input ended before it can recognize
anything.
UnclosedPI
The parser started to parse processing instruction (<?),
but the input ended before the ?> sequence was found.
UnclosedXmlDecl
The parser started to parse XML declaration (<?xml followed by \t, \r, \n, or ?),
but the input ended before the ?> sequence was found.
UnclosedComment
The parser started to parse comment (<!--) content, but the input ended
before the --> sequence was found.
UnclosedDoctype
The parser started to parse DTD (<!DOCTYPE) content, but the input ended
before the closing > character was found.
UnclosedCData
The parser started to parse <![CDATA[ content, but the input ended
before the ]]> sequence was found.
UnclosedTag
The parser started to parse tag content, but the input ended
before the closing > character was found.
UnclosedSingleQuotedAttributeValue
The parser started to parse tag content and currently inside of a quoted string (i.e. in an attribute value), but the input ended before the closing quote was found.
Note, that currently error location will point to a start of a tag (the < character)
instead of a start of an attribute value.
UnclosedDoubleQuotedAttributeValue
The parser started to parse tag content and currently inside of a quoted string (i.e. in an attribute value), but the input ended before the closing quote was found.
Note, that currently error location will point to a start of a tag (the < character)
instead of a start of an attribute value.