EscapeError

Enum EscapeError 

pub enum EscapeError {
    UnrecognizedEntity(Range<usize>, String),
    UnterminatedEntity(Range<usize>),
    InvalidCharRef(ParseCharRefError),
    TooManyNestedEntities,
}
Error for XML escape / unescape.

Variants



UnrecognizedEntity(Range<usize>, String)

Referenced entity in unknown to the parser.



UnterminatedEntity(Range<usize>)

Cannot find ; after &



InvalidCharRef(ParseCharRefError)

Attempt to parse character reference (&#<dec-number>; or &#x<hex-number>;) was unsuccessful, not all characters are decimal or hexadecimal numbers.



TooManyNestedEntities

Expanded more than maximum possible entities during attribute normalization.

Attribute normalization includes expanding of general entities (&entity;) which replacement text also could contain entities, which is also must be expanded. If more than 128 entities would be expanded, this error is returned.