EmptyElementHandling

Enum EmptyElementHandling 

pub enum EmptyElementHandling {
    SelfClosed,
    SelfClosedWithSpace,
    Expanded,
}
Available on crate feature serialize only.
Specifies how empty elements are serialized. The default is self-closed with no space before the slash.

Variants



SelfClosed

Empty elements will be written as <element/>. This is the default behavior.



SelfClosedWithSpace

The same, as SelfClosed, but an extra space will be written before the slash, so empty elements will be written as <element />. This is recommended by the W3C guidelines for XHTML.



Expanded

Empty elements will be expanded, as in: <element></element>.